@@ -1,6 +1,6 @@
 package Poet::Test::Util;
 BEGIN {
-  $Poet::Test::Util::VERSION = '0.02';
+  $Poet::Test::Util::VERSION = '0.03';
 }
 use Cwd qw(realpath);
 use File::Basename;
@@ -83,3 +83,24 @@ YAML::XS::Dump( {} );
 YAML::XS::Dump( {} );
 
 1;
+
+__END__
+=pod
+
+=head1 SEE ALSO
+
+L<Poet|Poet>
+
+=head1 AUTHOR
+
+Jonathan Swartz <swartz@pobox.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
