@@ -1,6 +1,6 @@
 package Poet::Util::Web;
 BEGIN {
-  $Poet::Util::Web::VERSION = '0.02';
+  $Poet::Util::Web::VERSION = '0.03';
 }
 use Data::Dumper;
 use URI;
@@ -51,7 +51,10 @@ sub make_uri {
     my ( $base, $params ) = @_;
 
     my $uri = URI->new($base);
-    $uri->query_form($params) if defined($params);
+    if ( defined($params) ) {
+        die "second argument must be a hashref" if ref($params) ne 'HASH';
+        $uri->query_form($params);
+    }
     return $uri->as_string;
 }
 
