@@ -1,6 +1,6 @@
 package Poet::t::Script;
 BEGIN {
-  $Poet::t::Script::VERSION = '0.02';
+  $Poet::t::Script::VERSION = '0.03';
 }
 use Capture::Tiny qw(capture);
 use Cwd qw(realpath);
@@ -45,3 +45,24 @@ print Dump([$env->root_dir, $env->lib_dir, $INC[0], $conf->get("foo.bar")]);
 ';
 
 1;
+
+__END__
+=pod
+
+=head1 SEE ALSO
+
+L<Poet|Poet>
+
+=head1 AUTHOR
+
+Jonathan Swartz <swartz@pobox.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
